@@ -10,6 +10,7 @@ pub mod options;
 pub mod plugins;
 pub mod theme;
 
+use crate::envs;
 use termion::input::TermRead;
 use zellij_tile::data::{InputMode, Key, ModeInfo, Palette, PluginCapabilities};
 
@@ -21,7 +22,7 @@ pub fn get_mode_info(
     capabilities: PluginCapabilities,
 ) -> ModeInfo {
     let keybinds = match mode {
-        InputMode::Normal | InputMode::Locked => Vec::new(),
+        InputMode::Normal | InputMode::Locked | InputMode::Prompt => Vec::new(),
         InputMode::Resize => vec![
             ("←↓↑→".to_string(), "Resize".to_string()),
             ("+-".to_string(), "Increase/Decrease size".to_string()),
@@ -57,7 +58,7 @@ pub fn get_mode_info(
         InputMode::Session => vec![("d".to_string(), "Detach".to_string())],
     };
 
-    let session_name = std::env::var("ZELLIJ_SESSION_NAME").ok();
+    let session_name = envs::get_session_name().ok();
 
     ModeInfo {
         mode,
