@@ -1,4 +1,5 @@
 use super::super::layout::*;
+use std::convert::TryInto;
 
 fn layout_test_dir(layout: String) -> PathBuf {
     let root = Path::new(env!("CARGO_MANIFEST_DIR"));
@@ -45,10 +46,10 @@ fn default_layout_merged_correctly() {
                 borderless: true,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(1)),
-                run: Some(Run::Plugin(Some(RunPlugin {
-                    path: "tab-bar".into(),
-                    ..Default::default()
-                }))),
+                run: Some(Run::Plugin(RunPlugin {
+                    location: RunPluginLocation::Zellij(PluginTag::new("tab-bar")),
+                    _allow_exec_host_cmd: false,
+                })),
             },
             Layout {
                 direction: Direction::Vertical,
@@ -62,16 +63,16 @@ fn default_layout_merged_correctly() {
                 borderless: true,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(2)),
-                run: Some(Run::Plugin(Some(RunPlugin {
-                    path: "status-bar".into(),
-                    ..Default::default()
-                }))),
+                run: Some(Run::Plugin(RunPlugin {
+                    location: RunPluginLocation::Zellij(PluginTag::new("status-bar")),
+                    _allow_exec_host_cmd: false,
+                })),
             },
         ],
         split_size: None,
         run: None,
     };
-    assert_eq!(merged_layout, tab_layout.into());
+    assert_eq!(merged_layout, tab_layout.try_into().unwrap());
 }
 
 #[test]
@@ -89,10 +90,10 @@ fn default_layout_new_tab_correct() {
                 borderless: true,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(1)),
-                run: Some(Run::Plugin(Some(RunPlugin {
-                    path: "tab-bar".into(),
-                    ..Default::default()
-                }))),
+                run: Some(Run::Plugin(RunPlugin {
+                    location: RunPluginLocation::Zellij(PluginTag::new("tab-bar")),
+                    _allow_exec_host_cmd: false,
+                })),
             },
             Layout {
                 direction: Direction::Horizontal,
@@ -106,16 +107,16 @@ fn default_layout_new_tab_correct() {
                 borderless: true,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(2)),
-                run: Some(Run::Plugin(Some(RunPlugin {
-                    path: "status-bar".into(),
-                    ..Default::default()
-                }))),
+                run: Some(Run::Plugin(RunPlugin {
+                    location: RunPluginLocation::Zellij(PluginTag::new("status-bar")),
+                    _allow_exec_host_cmd: false,
+                })),
             },
         ],
         split_size: None,
         run: None,
     };
-    assert_eq!(merged_layout, tab_layout.into());
+    assert_eq!(merged_layout, tab_layout.try_into().unwrap());
 }
 
 #[test]
@@ -207,7 +208,7 @@ fn three_panes_with_tab_merged_correctly() {
         split_size: None,
         run: None,
     };
-    assert_eq!(merged_layout, tab_layout.into());
+    assert_eq!(merged_layout, tab_layout.try_into().unwrap());
 }
 
 #[test]
@@ -229,7 +230,7 @@ fn three_panes_with_tab_new_tab_is_correct() {
         split_size: None,
         run: None,
     };
-    assert_eq!(merged_layout, tab_layout.into());
+    assert_eq!(merged_layout, tab_layout.try_into().unwrap());
 }
 
 #[test]
@@ -265,10 +266,10 @@ fn three_panes_with_tab_and_default_plugins_merged_correctly() {
                 borderless: false,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(1)),
-                run: Some(Run::Plugin(Some(RunPlugin {
-                    path: "tab-bar".into(),
-                    ..Default::default()
-                }))),
+                run: Some(Run::Plugin(RunPlugin {
+                    location: RunPluginLocation::Zellij(PluginTag::new("tab-bar")),
+                    _allow_exec_host_cmd: false,
+                })),
             },
             Layout {
                 direction: Direction::Vertical,
@@ -312,16 +313,16 @@ fn three_panes_with_tab_and_default_plugins_merged_correctly() {
                 borderless: false,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(2)),
-                run: Some(Run::Plugin(Some(RunPlugin {
-                    path: "status-bar".into(),
-                    ..Default::default()
-                }))),
+                run: Some(Run::Plugin(RunPlugin {
+                    location: RunPluginLocation::Zellij(PluginTag::new("status-bar")),
+                    _allow_exec_host_cmd: false,
+                })),
             },
         ],
         split_size: None,
         run: None,
     };
-    assert_eq!(merged_layout, tab_layout.into());
+    assert_eq!(merged_layout, tab_layout.try_into().unwrap());
 }
 
 #[test]
@@ -339,10 +340,10 @@ fn three_panes_with_tab_and_default_plugins_new_tab_is_correct() {
                 borderless: false,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(1)),
-                run: Some(Run::Plugin(Some(RunPlugin {
-                    path: "tab-bar".into(),
-                    ..Default::default()
-                }))),
+                run: Some(Run::Plugin(RunPlugin {
+                    location: RunPluginLocation::Zellij(PluginTag::new("tab-bar")),
+                    _allow_exec_host_cmd: false,
+                })),
             },
             Layout {
                 direction: Direction::Horizontal,
@@ -356,16 +357,16 @@ fn three_panes_with_tab_and_default_plugins_new_tab_is_correct() {
                 borderless: false,
                 parts: vec![],
                 split_size: Some(SplitSize::Fixed(2)),
-                run: Some(Run::Plugin(Some(RunPlugin {
-                    path: "status-bar".into(),
-                    ..Default::default()
-                }))),
+                run: Some(Run::Plugin(RunPlugin {
+                    location: RunPluginLocation::Zellij(PluginTag::new("status-bar")),
+                    _allow_exec_host_cmd: false,
+                })),
             },
         ],
         split_size: None,
         run: None,
     };
-    assert_eq!(merged_layout, tab_layout.into());
+    assert_eq!(merged_layout, tab_layout.try_into().unwrap());
 }
 
 #[test]
@@ -473,7 +474,7 @@ fn deeply_nested_tab_merged_correctly() {
         split_size: None,
         run: None,
     };
-    assert_eq!(merged_layout, tab_layout.into());
+    assert_eq!(merged_layout, tab_layout.try_into().unwrap());
 }
 
 #[test]
@@ -523,7 +524,7 @@ fn three_tabs_tab_one_merged_correctly() {
         run: None,
     };
 
-    assert_eq!(merged_layout, tab_layout.into());
+    assert_eq!(merged_layout, tab_layout.try_into().unwrap());
 }
 
 #[test]
@@ -573,7 +574,7 @@ fn three_tabs_tab_two_merged_correctly() {
         run: None,
     };
 
-    assert_eq!(merged_layout, tab_layout.into());
+    assert_eq!(merged_layout, tab_layout.try_into().unwrap());
 }
 
 #[test]
@@ -622,7 +623,7 @@ fn three_tabs_tab_three_merged_correctly() {
         split_size: None,
         run: None,
     };
-    assert_eq!(merged_layout, tab_layout.into());
+    assert_eq!(merged_layout, tab_layout.try_into().unwrap());
 }
 
 #[test]
@@ -660,7 +661,7 @@ fn no_tabs_merged_correctly() {
         run: None,
     };
 
-    assert_eq!(merged_layout, tab_layout.into());
+    assert_eq!(merged_layout, tab_layout.try_into().unwrap());
 }
 
 #[test]
@@ -716,5 +717,27 @@ fn no_layout_template_merged_correctly() {
         borderless: false,
     };
 
-    assert_eq!(merged_layout, tab_layout.into());
+    assert_eq!(merged_layout, tab_layout.try_into().unwrap());
+}
+
+#[test]
+fn session_name_to_layout_is_ok() {
+    let path = layout_test_dir("session-name-to-layout.yaml".into());
+    let layout_from_yaml = LayoutFromYaml::new(&path);
+    assert!(layout_from_yaml.is_ok());
+}
+
+#[test]
+fn session_name_to_layout_has_name() {
+    let path = layout_test_dir("session-name-to-layout.yaml".into());
+    let layout_from_yaml = LayoutFromYaml::new(&path);
+    let layout_template = layout_from_yaml.unwrap();
+    let session_layout = layout_template.session;
+
+    let expected_session = SessionFromYaml {
+        name: Some(String::from("zellij-session")),
+        attach: Some(true),
+    };
+
+    assert_eq!(expected_session, session_layout);
 }
